@@ -1,7 +1,7 @@
 """addressbook hooks
 
 :organization: Logilab
-:copyright: 2001-2009 LOGILAB S.A. (Paris, FRANCE), license is LGPL v2.
+:copyright: 2001-2011 LOGILAB S.A. (Paris, FRANCE), license is LGPL v2.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 :license: GNU Lesser General Public License, v2.1 - http://www.gnu.org/licenses
 """
@@ -23,7 +23,7 @@ class AutoSetLatLng(Hook):
         if not gmapkey:
             return
         geoattrs = set(('street', 'street2', 'postalcode', 'city', 'country'))
-        changed_attrs = set(self.entity.keys())
+        changed_attrs = set(self.entity.cw_edited)
         if (geoattrs & changed_attrs
             and not self.entity.get('latitude')
             and not self.entity.get('longitude')):
